@@ -86,6 +86,8 @@ SPECIAL_DIRS = [
     (ur"webaccess/searchuser\.py$", 'var/www/admin'),
 
     # JS in sub directories
+    (ur"modules/miscutil/etc/ckeditor_scientificchar/lang/.+\.js$", 'var/www/ckeditor/plugins/scientificchar/lang'),
+    (ur"modules/miscutil/etc/ckeditor_scientificchar/dialogs/scientificchar\.js$", 'var/www/ckeditor/plugins/scientificchar/dialogs'),
     (ur"modules/miscutil/etc/ckeditor_scientificchar/.+\.js$", 'var/www/ckeditor/plugins/scientificchar'),
     (ur"modules/miscutil/etc/ckeditor_scientificchar/lang/.+\.js$", 'var/www/ckeditor/plugins/scientificchar/lang'),
     (ur"modules/bibencode/lib/.+\.js", 'lib/python/invenio'),
@@ -152,6 +154,11 @@ IGNORE_FILES = [
     ur"modules/bibdocfile/lib/icon_migration_kit\.py$",
     ur"modules/webaccess/lib/collection_restrictions_migration_kit\.py$",
     ur"modules/webbasket/lib/webbasket_migration_kit\.py$",
+    # Old files
+    ur"modules/bibformat/etc/output_formats/UNTLD\.bfo$",
+    ur"modules/bibauthorid/lib/backbone-min\.js$",
+    ur"modules/bibauthorid/lib/bibauthorid_dbinterface_old\.py$",
+    ur"modules/bibrank/lib/bibrank_publication_grapher\.py$",
 ]
 
 IGNORE_FILES_RE = {re.compile(pattern , re.U|re.I) for pattern in IGNORE_FILES}
