@@ -78,10 +78,15 @@ def select_destination_path(filename, install_path=config.INSTALL_PATH,
             rel_path = rel_path.replace('%s/' % src_path, '')
             break
 
+    for regexp in config.IGNORE_FILES_RE:
+        m = regexp.match(rel_path)
+        if m:
+            return
+
     ext = get_extension(filename)
     lib_dir = dests[ext]
 
-    for regexp, dest_dir in config.SPECIAL_DIRS_RE.iteritems():
+    for regexp, dest_dir in config.SPECIAL_DIRS_RE:
         m = regexp.match(rel_path)
         if m:
             lib_dir = dest_dir % m.groupdict()
@@ -129,6 +134,8 @@ def reloader_loop(files, reloader=None, interval=1):
                 if dest and os.path.isfile(dest):
                     old_time = os.stat(dest).st_mtime
                 else:
+                    if dest:
+                        print 'missing file', filename, dest
                     old_time = mtime
 
             if mtime > old_time:
